<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el" sourcelanguage="en">
  <context>
    <name>CmdApproxCylinder</name>
    <message>
      <location filename="../../Command.cpp" line="205"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="206"/>
      <source>Cylinder</source>
      <translation>Κύλινδρος</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="207"/>
      <source>Approximate a cylinder</source>
      <translation>Approximate a cylinder</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Plane...</source>
      <translation>Επίπεδο...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Approximate a plane</source>
      <translation>Προσέγγιση ενός επιπέδου</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPolynomial</name>
    <message>
      <location filename="../../Command.cpp" line="318"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="319"/>
      <source>Polynomial surface</source>
      <translation>Polynomial surface</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="320"/>
      <source>Approximate a polynomial surface</source>
      <translation>Approximate a polynomial surface</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSphere</name>
    <message>
      <location filename="../../Command.cpp" line="271"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="272"/>
      <source>Sphere</source>
      <translation>Σφαίρα</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="273"/>
      <source>Approximate a sphere</source>
      <translation>Approximate a sphere</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <source>Approximate B-spline surface...</source>
      <translation>Προσέγγιση επιφάνειας B-spline...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="70"/>
      <source>Approximate a B-spline surface</source>
      <translation>Προσέγγιση μιας επιφάνειας B-spline</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshBoundary</name>
    <message>
      <location filename="../../Command.cpp" line="484"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="485"/>
      <source>Wire from mesh boundary...</source>
      <translation>Wire from mesh boundary...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="486"/>
      <source>Create wire from mesh boundaries</source>
      <translation>Create wire from mesh boundaries</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location filename="../../Command.cpp" line="550"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="551"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="552"/>
      <source>Poisson surface reconstruction</source>
      <translation>Ανακατασκευή επιφάνειας Poisson</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentation</name>
    <message>
      <location filename="../../Command.cpp" line="373"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="374"/>
      <source>Mesh segmentation...</source>
      <translation>Mesh segmentation...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>Create mesh segments</source>
      <translation>Δημιουργήστε τμήματα πλέγματος</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationFromComponents</name>
    <message>
      <location filename="../../Command.cpp" line="434"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="435"/>
      <source>From components</source>
      <translation>From components</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="436"/>
      <source>Create mesh segments from components</source>
      <translation>Create mesh segments from components</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationManual</name>
    <message>
      <location filename="../../Command.cpp" line="405"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="406"/>
      <source>Manual segmentation...</source>
      <translation>Manual segmentation...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="407"/>
      <source>Create mesh segments manually</source>
      <translation>Create mesh segments manually</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="584"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="585"/>
      <source>Structured point clouds</source>
      <translation>Δομημένα νέφη σημείων</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="586"/>
      <location filename="../../Command.cpp" line="587"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Τριγωνισμός των δομημένων νεφών σημείων</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="184"/>
      <source>Fit plane</source>
      <translation>Εφαρμογή επιπέδου</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="215"/>
      <source>Fit cylinder</source>
      <translation>Εφαρμογή κυλίνδρου</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="281"/>
      <source>Fit sphere</source>
      <translation>Εφαρμογή σφαίρας</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="329"/>
      <source>Fit polynomial surface</source>
      <translation>Εφαρμόγη πολυωνυμικής επιφάνειας</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="595"/>
      <source>View triangulation</source>
      <translation>Προβολή τριγωνισμού</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="150"/>
      <source>Placement</source>
      <translation>Τοποθέτηση</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="222"/>
      <source>Fit B-Spline</source>
      <translation>Προσαρμογή B-Spline</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="91"/>
      <source>Poisson reconstruction</source>
      <translation>Ανακατασκευή Poisson</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.cpp" line="257"/>
      <source>Segmentation</source>
      <translation>Κατάτμηση</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="14"/>
      <source>Fit B-spline surface</source>
      <translation>Προσαρμογή στην επιφάνεια B-spline</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="20"/>
      <source>u-Direction</source>
      <translation>Διεύθυνση u</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="26"/>
      <location filename="../../FitBSplineSurface.ui" line="93"/>
      <source>Degree</source>
      <translation>Βαθμός</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="55"/>
      <location filename="../../FitBSplineSurface.ui" line="122"/>
      <source>Control points</source>
      <translation>Σημεία ελέγχου</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="87"/>
      <source>v-Direction</source>
      <translation>Διεύθυνση v</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="154"/>
      <source>Settings</source>
      <translation>Ρυθμίσεις</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="160"/>
      <source>Iterations</source>
      <translation>Επαναλήψεις</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="189"/>
      <source>Size factor</source>
      <translation>Παράγοντας μεγέθους</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="218"/>
      <source>User-defined u/v directions</source>
      <translation>Κατευθύνσεις u/v ορισμένες από τον χρήστη</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="231"/>
      <source>Create placement</source>
      <translation>Δημιουργία τοποθέτησης</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="238"/>
      <source>Smoothing</source>
      <translation>Εξομάλυνση</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="247"/>
      <source>Total Weight</source>
      <translation>Συνολικό Βάρος</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="276"/>
      <source>Length of gradient</source>
      <translation>Μήκος βαθμίδας</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="305"/>
      <source>Bending energy</source>
      <translation>Ενέργεια κάμψης</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="334"/>
      <source>Curvature variation</source>
      <translation>Μεταβολή καμπυλότητας</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="161"/>
      <location filename="../../FitBSplineSurface.cpp" line="229"/>
      <source>Input error</source>
      <translation>Σφάλμα εισαγωγής</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="201"/>
      <source>Wrong selection</source>
      <translation>Λάθος επιλογή</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="202"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Παρακαλώ επιλέξτε ένα αντικείμενο τοποθέτησης για να έχετε τον τοπικό προσανατολισμό.</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="20"/>
      <source>Parameters</source>
      <translation>Παράμετροι</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="26"/>
      <source>Octree depth</source>
      <translation>Βάθος οκταδικού δένδρου</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="46"/>
      <source>Solver divide</source>
      <translation>Διαίρεση του επιλυτή</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="66"/>
      <source>Samples per node</source>
      <translation>Δείγματα ανά κόμβο</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="98"/>
      <source>Input error</source>
      <translation>Σφάλμα εισαγωγής</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <location filename="../../Command.cpp" line="563"/>
      <source>Wrong selection</source>
      <translation>Λάθος επιλογή</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Please select a point cloud or mesh.</source>
      <translation>Παρακαλώ επιλέξτε ένα σημείο σύννεφο ή πλέγμα.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="564"/>
      <source>Please select a single point cloud.</source>
      <translation>Παρακαλώ επιλέξτε ένα νέφος σημείων.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="617"/>
      <source>View triangulation failed</source>
      <translation>Η προβολή τριγωνισμού απέτυχε</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::Segmentation</name>
    <message>
      <location filename="../../Segmentation.ui" line="14"/>
      <source>Mesh segmentation</source>
      <translation>Τμηματοποίηση πλέγματος</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="20"/>
      <source>Smooth mesh</source>
      <translation>Εξομάλυνση πλέγματος</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="37"/>
      <source>Plane</source>
      <translation>Επίπεδο</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="46"/>
      <source>Curvature tolerance</source>
      <translation>Ανοχή καμπυλότητας</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="63"/>
      <source>Distance to plane</source>
      <translation>Απόσταση μέχρι το τέλος</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="80"/>
      <source>Minimum number of faces</source>
      <translation>Ελάχιστος αριθμός όψεων</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="100"/>
      <source>Create mesh from unused triangles</source>
      <translation>Δημιουργήστε πλέγμα από αχρησιμοποίητα τρίγωνα</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="107"/>
      <source>Create compound</source>
      <translation>Δημιουργία στοιχείου</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::SegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.ui" line="14"/>
      <source>Manual segmentation</source>
      <translation>Χειροκίνητη τμηματοποίηση</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="20"/>
      <source>Select</source>
      <translation>Επιλέξτε</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="41"/>
      <source>Region</source>
      <translation>Περιοχή</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="61"/>
      <source>All</source>
      <translation>Όλα</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="81"/>
      <source>Components</source>
      <translation>Στοιχεία</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="88"/>
      <source>&lt; faces than</source>
      <translation>&lt; όψεις από</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="98"/>
      <source>Pick triangle</source>
      <translation>Διαλέξτε τρίγωνο</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="105"/>
      <source>Select whole component</source>
      <translation>Επιλέξτε ολόκληρο στοιχείο</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="112"/>
      <source>Clear</source>
      <translation>Εκκαθάριση</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="122"/>
      <source>Plane</source>
      <translation>Επίπεδο</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="128"/>
      <location filename="../../SegmentationManual.ui" line="181"/>
      <location filename="../../SegmentationManual.ui" line="234"/>
      <source>Detect</source>
      <translation>Εντοπισμός</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="135"/>
      <location filename="../../SegmentationManual.ui" line="188"/>
      <location filename="../../SegmentationManual.ui" line="241"/>
      <source>Tolerance</source>
      <translation>Ανοχή</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="155"/>
      <location filename="../../SegmentationManual.ui" line="208"/>
      <location filename="../../SegmentationManual.ui" line="261"/>
      <source>Minimum number of faces</source>
      <translation>Ελάχιστος αριθμός όψεων</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="175"/>
      <source>Cylinder</source>
      <translation>Κύλινδρος</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="228"/>
      <source>Sphere</source>
      <translation>Σφαίρα</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="281"/>
      <source>Region options</source>
      <translation>Επιλογές περιοχής</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="287"/>
      <source>Respect only visible triangles</source>
      <translation>Διατήρηση μόνο των ορατών τριγώνων</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="297"/>
      <source>Respect only triangles with normals facing screen</source>
      <translation>Διατήρηση μόνο των τριγώνων των οποίων τα κάθετα διανύσματα τείνουν προς την οθόνη</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="310"/>
      <source>Segmentation</source>
      <translation>Κατάτμηση</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="316"/>
      <source>Cut segment from mesh</source>
      <translation>Περικοπή τμήματος από πλέγμα</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="326"/>
      <source>Hide segment</source>
      <translation>Απόκρυψη τμήματος</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::TaskSegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.cpp" line="333"/>
      <source>Create</source>
      <translation>Δημιουργήστε</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Reverse Engineering</source>
      <translation>Αντίστροφη Μηχανική</translation>
    </message>
  </context>
</TS>
